==> nan_photo_selector-0.0.3.tar.gz: lib/commonUploadImgWidget.dart <==

import 'dart:io';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_native_image/flutter_native_image.dart';
import 'package:image_picker/image_picker.dart';
import 'package:nan_photo_selector/NanCommonConst.dart';
import 'package:nan_photo_selector/NanCommonWidget.dart';
import 'package:nan_photo_selector/NanShowModalBottomSheetUtils.dart';
import 'package:nan_photo_selector/nanPhotoViewPage.dart';
import 'package:toast/toast.dart';

class NanCommonUploadImgWidget extends StatefulWidget{
  // List<File> imgFileList =[]
  final String uploadTitle;
  final  List? images;
  // final Function(File file, Widget imageWidget) onSelected;
  final Function(List<File> fileList, List<Widget> images)? onSelected;
  final Function(int index)? onDelete;
  final bool isFinish;
  final int imgMaxNum;
  final String photoType;
  final bool isRequired;
  final bool isEnableCheckPhoto;//是否支持图片查看，默认支持
  final String deleteImg;//删除图片
  final int rowCount;//每一行有多少张图片，默认4张
  final String tip;//图片不限制数量的提示语
  NanCommonUploadImgWidget({
    Key? key,
    this.uploadTitle ="现场图片",
    this.images,
    this.onSelected,
    this.onDelete,
    this.isFinish = false,
    this.imgMaxNum = 9,
    this.photoType = PhotoType.All,
    this.isRequired = true,
    this.isEnableCheckPhoto = true,
    this.deleteImg = "delete2",
    this.rowCount = 4,
    this.tip = "可上传多张图片"
  }):super(key:key);

  @override
  _NanCommonUploadImgWidgetState createState() => _NanCommonUploadImgWidgetState();
}

class _NanCommonUploadImgWidgetState extends State<NanCommonUploadImgWidget>{

  List choiceList = [{"name":"相机"},{"name":"相册"}];

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    widget.images!.add(loadAssetImage('imageSel',width: kScreenWidth/4,height: kScreenWidth/4));
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Column(
      children: <Widget>[
        reportRecordDetailWidget(widget.uploadTitle,isRequired: widget.isRequired,leftTitleColor: Colors.black,fSize: 15,fontWeight: FontWeight.bold),
        Divider(height: 1,),
        widget.rowCount == null ? Container(
          color: Colors.white,
          height: 80,
          alignment: Alignment.center,
          child: Text("请设置每行图片数量",style: TextStyle(color: Colors.redAccent,fontSize: 20),),
        ):imgItemWidget(),
        commonUploadTip(tip: widget.imgMaxNum == null ? '${widget.tip}':'* 最多只能上传${widget.imgMaxNum}张'),
      ],
    );
  }

/*======================================widget=============================================*/
Widget firstImgWidget({index}){//第一个选择相片按钮
  return Container(
    width: kScreenWidth/4,
    height: kScreenWidth/4,
    child: InkWell(
      child: widget.images![index],
      onTap: (){
        _openGallery();
      },
    ),
  );
}

Widget otherImgWidget({index,imgOnTap}){//其它展示的图片
  return Container(
    width: kScreenWidth/4,
    height: kScreenWidth/4,
    child: Stack(
      children: <Widget>[
        InkWell(
          child: widget.images![index],
          onTap: imgOnTap,
        ),
        Positioned(
          width: 20,
          height: 20,
          right: 0,
          top: 0,
          child: Offstage(
            offstage: widget.onDelete == null,
            child: loadAssetImage(widget.deleteImg,onTap: (){
              if(widget.isFinish){
                return;
              }
              widget.onDelete!(index);
            }),
          )
        )
      ],
    ),
  ); 
}

Widget imgItemWidget(){//图片模块
  return Container(
    color: Colors.white,
    child: CustomScrollView(
      physics: const NeverScrollableScrollPhysics(),
      shrinkWrap: true,
      slivers: <Widget>[
        SliverGrid(
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: widget.rowCount,
            crossAxisSpacing: 1.0,
            mainAxisSpacing: 1.0,
            childAspectRatio: 1.0,
          ),
          delegate: SliverChildBuilderDelegate((BuildContext context,int index){
            if(index == 0){
              return firstImgWidget(index: index);
            }else{
              return otherImgWidget(index: index,imgOnTap: (){
                if (!widget.isEnableCheckPhoto) return;
                List  photoList = filtrateLocalList();
                Navigator.push(context, MaterialPageRoute(builder: (context)=>PhotoViewPage(photoList: photoList,index: index-1,checkPhotoType: CheckPhotoType.LocalType,)));
              });
            }
          },
          childCount: widget.images!.length
        ), 
        )
      ],
    ),
  );
}

/*======================================method=============================================*/
  /*相册*/
  _openGallery() async {
    FocusScope.of(context).requestFocus(FocusNode());//隐藏键盘


    if(widget.imgMaxNum != null && (widget.images!.length> widget.imgMaxNum)){
      Toast.show("最多只能上传${widget.imgMaxNum}", context,gravity: Toast.CENTER);
      return;
    }
    switch (widget.photoType) {
      case PhotoType.Camera:
        phontSelect(0);
        break;
      case PhotoType.Phonto:
        phontSelect(1);
        break;  
      default:
        photoAll();
        break;
    }
  }

  void photoAll(){//相机与相册
    NanShowModalBottomSheetUtils.photoAll(context,choiceList: choiceList,selectResult: (int index){
      phontSelect(index);
    });
  }

  void phontSelect(int index) async{//相机与相册
    if(index == 0){
      var image = await ImagePicker.pickImage(source: index==1?ImageSource.gallery:ImageSource.camera);
      if(image == null) return;
      bool dirBool = await image.exists();
      NanShowModalBottomSheetUtils.showUploadDialog(context,radius: 0,isDismiss: false,tipMsg: "图片压缩中...");
      File fileTest = image;
      File file2 = await FlutterNativeImage.compressImage(fileTest.path,quality: 70, percentage: 50);//压缩图片
      Navigator.pop(context);
      if(!dirBool){
        return;
      }
      widget.onSelected!([file2],[uploadImageView(file2)]);
    }else{
      _openFileExplorer();
    }

  }

  void _openFileExplorer() async {//相册选择
    List<File> fileList = [];
    List<Widget> images = [];
    String? _extension;
    Map<String, String> _paths = {};
    try {
      _paths = await FilePicker.getMultiFilePath(
        type: FileType.image,
        onFileLoading:(status){
          
        },
        allowedExtensions: (_extension?.isNotEmpty ?? false)
            ? _extension?.replaceAll(' ', '')?.split(',')
            : null,
      );
    } on PlatformException catch (e) {
      return;
    }

    if (_paths == null) return;
    if(widget.imgMaxNum != null && ((widget.images!.length + _paths.length) > widget.imgMaxNum+1)){
      Toast.show("最多只能上传${widget.imgMaxNum}", context,gravity: Toast.CENTER);
      return;
    }

    if (!mounted) return;
    NanShowModalBottomSheetUtils.showUploadDialog(context,radius: 0,isDismiss: false,tipMsg: "图片压缩中...");
    for(String fileNames in _paths.keys){
      String filePath = _paths[fileNames] as String;
      File file = File(filePath);
      File file2 = await FlutterNativeImage.compressImage(file.path,quality: 70, percentage: 50);//压缩图片
      images.add(uploadImageView(file2));
      fileList.add(file2);
    }
    Navigator.pop(context);
    widget.onSelected!(fileList,images);
    // widget.onSelected(pathList, fileList);

  }

  //过滤一下本地图片地址
  List filtrateLocalList(){
    List  photoList = [];
    for (var i = 0; i < widget.images!.length; i++) {

      if (i==0) continue;
      Image image = widget.images![i];
      FileImage fileImage = image.image as FileImage;
      File file = fileImage.file;
      String filePath = file.path;
      photoList.add(filePath);
    }
    return photoList;
  }

}

==> nan_photo_selector-0.0.8.tar.gz: lib/commonUploadImgWidget.dart <==

import 'dart:io';
import 'package:camera/camera.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_native_image/flutter_native_image.dart';
import 'package:image_picker/image_picker.dart';
import 'package:nan_photo_selector/NanCommonConst.dart';
import 'package:nan_photo_selector/NanCommonWidget.dart';
import 'package:nan_photo_selector/NanShowModalBottomSheetUtils.dart';
import 'package:nan_photo_selector/nanPhotoViewPage.dart';
import 'package:toast/toast.dart';

class NanCommonUploadImgWidget extends StatefulWidget{
  // List<File> imgFileList =[]
  final String uploadTitle;
  final List images;
  // final Function(File file, Widget imageWidget) onSelected;
  final Function(List<File> fileList, List<Widget> images) onSelected;
  final Function(int index) onDelete;
  final bool isFinish;
  final int imgMaxNum;
  final String photoType;
  final bool isRequired;
  final bool isEnableCheckPhoto;//是否支持图片查看，默认支持
  final String deleteImg;//删除图片
  final int rowCount;//每一行有多少张图片，默认4张
  final String tip;//图片不限制数量的提示语
  NanCommonUploadImgWidget({
    Key key,
    this.uploadTitle ="现场图片",
    this.images,
    this.onSelected,
    this.onDelete,
    this.isFinish = false,
    this.imgMaxNum = 9,
    this.photoType = PhotoType.All,
    this.isRequired = true,
    this.isEnableCheckPhoto = true,
    this.deleteImg = "delete2",
    this.rowCount = 4,
    this.tip = "可上传多张图片"
  }):super(key:key);

  @override
  _NanCommonUploadImgWidgetState createState() => _NanCommonUploadImgWidgetState();
}

class _NanCommonUploadImgWidgetState extends State<NanCommonUploadImgWidget>{

  List choiceList = [{"name":"相机"},{"name":"相册"}];
  CameraController _cameraController;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    // _cameraController =
    //     CameraController(currentCamera, ResolutionPreset.veryHigh);
    widget.images.add(loadAssetImage('imageSel',width: kScreenWidth/4,height: kScreenWidth/4));
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Column(
      children: <Widget>[
        reportRecordDetailWidget(widget.uploadTitle,isRequired: widget.isRequired,leftTitleColor: Colors.black,fSize: 15,fontWeight: FontWeight.bold),
        Divider(height: 1,),
        widget.rowCount == null ? Container(
          color: Colors.white,
          height: 80,
          alignment: Alignment.center,
          child: Text("请设置每行图片数量",style: TextStyle(color: Colors.redAccent,fontSize: 20),),
        ):imgItemWidget(),
        commonUploadTip(tip: widget.imgMaxNum == null ? '${widget.tip}':'* 最多只能上传${widget.imgMaxNum}张'),
      ],
    );
  }

/*======================================widget=============================================*/
Widget firstImgWidget({index}){//第一个选择相片按钮
  return Container(
    width: kScreenWidth/4,
    height: kScreenWidth/4,
    child: InkWell(
      child: widget.images[index],
      onTap: (){
        _openGallery();
      },
    ),
  );
}

Widget otherImgWidget({index,imgOnTap}){//其它展示的图片
  return Container(
    width: kScreenWidth/4,
    height: kScreenWidth/4,
    child: Stack(
      children: <Widget>[
        InkWell(
          child: widget.images[index],
          onTap: imgOnTap,
        ),
        Positioned(
          width: 20,
          height: 20,
          right: 0,
          top: 0,
          child: Offstage(
            offstage: widget.onDelete == null,
            child: loadAssetImage(widget.deleteImg,onTap: (){
              if(widget.isFinish){
                return;
              }
              widget.onDelete(index);
            }),
          )
        )
      ],
    ),
  ); 
}

Widget imgItemWidget(){//图片模块
  return Container(
    color: Colors.white,
    child: CustomScrollView(
      physics: const NeverScrollableScrollPhysics(),
      shrinkWrap: true,
      slivers: <Widget>[
        SliverGrid(
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: widget.rowCount,
            crossAxisSpacing: 1.0,
            mainAxisSpacing: 1.0,
            childAspectRatio: 1.0,
          ),
          delegate: SliverChildBuilderDelegate((BuildContext context,int index){
            if(index == 0){
              return firstImgWidget(index: index);
            }else{
              return otherImgWidget(index: index,imgOnTap: (){
                if (!widget.isEnableCheckPhoto) return;
                List  photoList = filtrateLocalList();
                Navigator.push(context, MaterialPageRoute(builder: (context)=>PhotoViewPage(photoList: photoList,index: index-1,checkPhotoType: CheckPhotoType.LocalType,)));
              });
            }
          },
          childCount: widget.images.length
        ), 
        )
      ],
    ),
  );
}

/*======================================method=============================================*/
  /*相册*/
  _openGallery() async {
    FocusScope.of(context).requestFocus(FocusNode());//隐藏键盘


    if(widget.imgMaxNum != null && (widget.images.length> widget.imgMaxNum)){
      Toast.show("最多只能上传${widget.imgMaxNum}", context,gravity: Toast.CENTER);
      return;
    }
    switch (widget.photoType) {
      case PhotoType.Camera:
        phontSelect(0);
        break;
      case PhotoType.Phonto:
        phontSelect(1);
        break;  
      default:
        photoAll();
        break;
    }
  }

  void photoAll(){//相机与相册
    NanShowModalBottomSheetUtils.photoAll(context,choiceList: choiceList,selectResult: (int index){
      phontSelect(index);
    });
  }

  void phontSelect(int index) async{//相机与相册
    if(index == 0){

      var image = await ImagePicker.pickImage(source: index==1?ImageSource.gallery:ImageSource.camera);
      if(image == null) return;
      bool dirBool = await image.exists();
      NanShowModalBottomSheetUtils.showUploadDialog(context,radius: 0,isDismiss: false,tipMsg: "图片压缩中...");
      File fileTest = image;
      File file2 = await FlutterNativeImage.compressImage(fileTest.path,quality: 70, percentage: 50);//压缩图片
      Navigator.pop(context);
      // if(!dirBool){
      //   return;
      // }
      widget.onSelected([file2],[uploadImageView(file2)]);
    }else{
      _openFileExplorer();
    }

  }

  void _openFileExplorer() async {//相册选择
    List<File> fileList = [];
    List<Widget> images = [];
    String _extension;
    Map<String, String> _paths = {};
    try {
      _paths = await FilePicker.getMultiFilePath(
        type: FileType.image,
        onFileLoading:(status){
          
        },
        allowedExtensions: (_extension?.isNotEmpty ?? false)
            ? _extension?.replaceAll(' ', '')?.split(',')
            : null,
      );
    } on PlatformException catch (e) {
      return;
    }

    if (_paths == null) return;
    if(widget.imgMaxNum != null && ((widget.images.length + _paths.length) > widget.imgMaxNum+1)){
      Toast.show("最多只能上传${widget.imgMaxNum}", context,gravity: Toast.CENTER);
      return;
    }

    if (!mounted) return;
    NanShowModalBottomSheetUtils.showUploadDialog(context,radius: 0,isDismiss: false,tipMsg: "图片压缩中...");
    for(String fileNames in _paths.keys){
      String filePath = _paths[fileNames] as String;
      File file = File(filePath);
      File file2 = await FlutterNativeImage.compressImage(file.path,quality: 70, percentage: 50);//压缩图片
      images.add(uploadImageView(file2));
      fileList.add(file2);
    }
    Navigator.pop(context);
    widget.onSelected(fileList,images);
    // widget.onSelected(pathList, fileList);

  }

  //过滤一下本地图片地址
  List filtrateLocalList(){
    List  photoList = [];
    for (var i = 0; i < widget.images.length; i++) {

      if (i==0) continue;
      Image image = widget.images[i];
      FileImage fileImage = image.image as FileImage;
      File file = fileImage.file;
      String filePath = file.path;
      photoList.add(filePath);
    }
    return photoList;
  }

}
